var deviceManager = new pcprox.DeviceManager();
var configurationFlags = new pcprox.ConfigurationFlags();
var configurationFlags2 = new pcprox.ConfigurationFlags2();
var idBItCounts = new pcprox.IdBItCounts();
var configuration = new pcprox.Configuration();
var configFlags3 = new pcprox.ConfigurationFlags3();
var idDisplayParameter = new pcprox.IdDisplayParameter();
var isDeviceConnect = false;
var actConfig;
var isBSndFacEnabled;
var containActConfig;
var maximumBeepCount = 5;
var islongBeep = false;
var checkBeep = false;
var beepCount = 1;

function openTab(tabName) {
    let tabIndex;
    let tabs = document.getElementsByClassName("tab");
    for (tabIndex = 0; tabIndex < tabs.length; tabIndex++) {
        tabs[tabIndex].style.display = "none";
    }
    document.getElementById(tabName).style.display = "block";
}

async function connect() {
    isDeviceConnect = await deviceManager.connect();
    if (isDeviceConnect) {
        alert("Device Connected!");
        let partnumber = await deviceManager.getPartNumber();
        let fwFileName = await deviceManager.GetFWFileName();
        let fwFileVersion = await deviceManager.GetFullFWVersion();
        let version = await deviceManager.getLibVersion();
        let isBetaVersion = await deviceManager.getLibraryVersion_Beta();
        let webSdkVersion = version[0] + '.' + version[1] + '.' + version[2] + isBetaVersion;
        await deviceManager.readCFG();
        logicalUnitID = await configuration.getLuid()
        actConfig = await deviceManager.getActConfig();
        containActConfig = actConfig;
        document.getElementById('config').value = parseInt(actConfig) - 1;
        await getBeeperVolume();
        await getCfgFlags_bHaltKBSnd();
        await getCfgFlags_bFrcBitCntEx();
        await getCfgFlags_bSndFac();
        await getCfgFlags_bStripFac();
        await getLeadParityBitCnt();
        await getTrailParityBitCnt();
        await getCfgFlags_bFixLenDsp();
        await getCfgFlags_bSndOnRx();
        await getCfgFlags2_bWiegInvData();
        await getCfgFlags2_bRevWiegBits();
        await getCfgFlags2_bBeepID();
        await getCfgFlags2_bRevBytes();
        await getCardPriority();
        getCardType();
        await getExtendedPrecisionMath();
        await getIdExtendedPreMath();
        await getUseNumericKeypad();
        await getDisplayHexInLowercase();
        await getIDBitCnts_iIDBitCnt();
        await getCfgFlags_bFrcBitCntEx();
        await getIDDispParms_iFACDispLen();
        await getIDDispParms_iIDDispLen();
        await getAZERTYShiftLock();
        await getDID();
        await getCfgFlags3_bSndSFID();
        await getCfgFlags3_bSndSFFC();
        WriteLog(partnumber, "vendor")
        WriteLog(actConfig, "actConfigID");
        WriteLog(fwFileName, "FWFile");
        WriteLog(fwFileVersion, "FWFileVersion");
        WriteLog(webSdkVersion, "webSdkid");
        WriteLog(logicalUnitID, "LogicalUnitId");
    }
}

async function isBLEdevice() {
    var isBLEpresent = await deviceManager.isBLEPresent();
    let statusOfBLEReader;
    if (isBLEpresent) {
        statusOfBLEReader = 1 + ":Yes";
    } else {
        statusOfBLEReader = 0 + ":No";
    }
    WriteLog(statusOfBLEReader, "isBlePresent");
}

async function resetToFactoryDefaults() {
    let confirmResult = confirm("Are you sure you want to reset the configuration?");
    if(confirmResult) {
        let resetToFactDflts = await deviceManager.resetFactoryDflts();
        if(resetToFactDflts) {
            alert("Reset to factory defaults successful");
        } else {
            alert("Reset to factory defaults faild");
        }
    }
}

async function uploadHWG() {
    if (isDeviceConnect) {
        let file = document.getElementById('uploadHWG').files[0];
        let fileExtension = file.name.split('.').pop();
        if(fileExtension === 'hwg+') {
            let hwgFileStatus = await deviceManager.readDevCfgFmFile(file);
            if (hwgFileStatus) {
                alert("HWG+ File loaded!");
            } else {
                alert("HWG+ file not loaded");
            }
        } else {
            alert("Please select a .hwg+ file");
        }
    }
    else {
        alert("No Device Connected");
    }
}

async function uploadSecureHWG() {
    if (isDeviceConnect) {
        let file = document.getElementById('uploadSecureHWG').files[0];
        let fileExtension = file.name.split('.').pop();
        if(fileExtension === 'hwg+') {
            let secureHWGFileStatus = await deviceManager.readDevCfgFromSecureFile(file);
            if (secureHWGFileStatus) {
                alert("Secure HWG+ File loaded!");
            } else {
                alert("Secure HWG+ file not loaded");
            }
        } else {
            alert("Please select a .hwg+ file");
        }
    }
    else {
        alert("No Device Connected");
    }
}


async function openFileExplorer() {
    var fileInput = document.getElementById('uploadHWG');
    fileInput.click();
}

async function openSecureFileExplorer() {
    var fileInput = document.getElementById('uploadSecureHWG');
    fileInput.click();
}

async function saveHWG() {
    if (isDeviceConnect) {
        var link = document.getElementById('saveHWGFile');
        let fileName = window.prompt('Enter the file name to save the HWG+ file');
        if(fileName === null) {
            return;
        }
        let fileNameToSave = fileName.trim() || 'noname';
        let isFileCreate = await deviceManager.writeDevCfgToFile(fileNameToSave);
        if (isFileCreate) {
            alert('File Successfully Created');
        } else {
            alert('File is not created');
        }
    }
    else {
        alert("No Device Connected");
    }
}

async function saveSecureHWG() {
    if (isDeviceConnect) {
        var link = document.getElementById('saveSecureHwg');
        let fileName = window.prompt('Enter the file name to save the HWG+ file');
        if(fileName === null) {
            return;
        }
        let fileNameToSave = fileName.trim() || 'noname';
        let isFileCreated = await deviceManager.writeDevCfgToSecureFile(fileNameToSave);
        if (isFileCreated) {
            alert('File Successfully Created');
        } else {
            alert('File is not created');
        }
    }
    else {
        alert("No Device Connected");
    }
}

async function getQueuedID() {
    await deviceManager.getQueuedID();
    let bitsOfCard = await deviceManager.getQueuedID_index(32);
    let age = await deviceManager.getQueuedID_index(33);
    let overRun = await deviceManager.getQueuedID_index(34);
    let lockoutTimer = await deviceManager.getQueuedID_index(35);
    let data = await dataConvertToString();
    let more = "";
    let data1 = data.slice(0, 8).join(' ');
    let data2 = data.slice(8, 16).join(' ');
    let data3 = data.slice(16, 24).join(' ');
    let data4 = data.slice(24, 32).join(' ');
    let ageF = age / (1000 / 48);
    let ageM = Math.floor(Math.floor(ageF) / 60);
    ageM = ("0" + ageM).toString();
    let ageS = Math.floor(Math.floor(ageF) % 60).toString().slice(-2);
    ageS = ("0" + ageS).slice(-2);
    if (age === 65535) {
        more = '>';
    }

    age = more + "00:" + ageM + ":" + ageS + "(" + age + "x48ms)";

    let final = "Queued ID :" + bitsOfCard + " Bits" + `\n\n` + data1 + `\n` + data2 + `\n` + data3 + `\n` + data4 + `\n\n` + "Age : " + age + `\n` + "Over runs:" + overRun + `\n` + "Lockout timer :" + lockoutTimer;
    WriteLog(final, "databytes");
}

async function dataConvertToString() {
    var bufferSize = 32;
    var queuedId = '';
    for (let index = bufferSize - 1; index >= 0; index--) {
        let value = await deviceManager.getQueuedID_index(index);
        let bufferValue = value.toString(16).toUpperCase();
        bufferValue = ('00' + bufferValue).substring(bufferValue.length);
        queuedId += bufferValue;
    }
    let finalData = queuedId.match(/.{1,2}/g);
    return finalData;
}

async function getDID() {
    let getDid = await configuration.getDID();
    let major = (getDid >> 8 & 255).toString(16);
    let minor = (getDid >> 4 & 15).toString(16);
    let build = (getDID & 5).toString(16);
    let FirmwarVersion = major + '.' + minor + '.' + build;
    WriteLog(FirmwarVersion, "usbFirmwareID");
}

async function setLUID() {
    let setLogicalUit = document.getElementById("LogicalUnitId").value;
    await configuration.setLuid(setLogicalUit);
}

async function getFirmwareVersion() {
    let firmware = await deviceManager.getFirmwareVersion();
    WriteLog(firmware, "FWtextbox")
}

async function decreaseLeadParityBitCnt() {
    let currentLPValue = parseInt(document.getElementById('leadParityBitCnt').value);
    if (currentLPValue > 0 && currentLPValue <= 142) {
        document.getElementById('leadParityBitCnt').value = currentLPValue - 1;
        await setLeadParityBitCnt(currentLPValue - 1);
    }
}

async function decreaseTrailParityBitCnt() {
    let currentTPValue = parseInt(document.getElementById('trailParityBitCnt').value);
    if (currentTPValue > 0 && currentTPValue <= 142) {
        document.getElementById('trailParityBitCnt').value = currentTPValue - 1;
        await setTrailParityBitCnt(currentTPValue - 1);
    }
}

async function increaseLeadParityBitCnt() {
    let currentLPValue = parseInt(document.getElementById('leadParityBitCnt').value);
    if (currentLPValue >= 0 && currentLPValue < 142) {
        document.getElementById('leadParityBitCnt').value = currentLPValue + 1;
        await setLeadParityBitCnt(currentLPValue + 1);
        return;
    }
    if (isNaN(currentLPValue)) {
        document.getElementById('leadParityBitCnt').value = 1
    }
}

async function increaseTrailParityBitCnt() {
    let currentTPValue = parseInt(document.getElementById('trailParityBitCnt').value);
    if (currentTPValue >= 0 && currentTPValue < 142) {
        document.getElementById('trailParityBitCnt').value = currentTPValue + 1;
        await setTrailParityBitCnt(currentTPValue + 1);
        return;
    }
    if (isNaN(currentTPValue)) {
        document.getElementById('trailParityBitCnt').value = 1
    }
}

async function setLeadParityBitCnt(LPValue) {
    if (isNaN(LPValue)) {
        document.getElementById('leadParityBitCnt').value = 0;
        await idBItCounts.setIDBitCnts_iLeadParityBitCnt(0, actConfig - 1);
        return;
    }
    await idBItCounts.setIDBitCnts_iLeadParityBitCnt(LPValue, actConfig - 1);
}

async function setonlyCardReadBit() {
    let getonlyCardValue = document.getElementById("onlyCardReadCountID").value;
    if (isNaN(getonlyCardValue)) {
        document.getElementById('onlyCardReadCountID').value = 0;
        await idBItCounts.setIDBitCnts_iTotalBitCnt(0, actConfig);
        return;
    }
    await idBItCounts.setIDBitCnts_iTotalBitCnt(parseInt(getonlyCardValue), actConfig);
}

async function setTrailParityBitCnt(TPValue) {
    if (isNaN(TPValue)) {
        document.getElementById('trailParityBitCnt').value = 0;
        await idBItCounts.setIDBitCnts_iTrailParityBitCnt(0, actConfig - 1);
        return;
    }
    await idBItCounts.setIDBitCnts_iTrailParityBitCnt(TPValue, actConfig - 1);
}

async function getLeadParityBitCnt() {
    let leadValue = await idBItCounts.getIDBitCnts_iLeadParityBitCnt(actConfig - 1);
    document.getElementById('leadParityBitCnt').value = parseInt(leadValue);
}

async function getTrailParityBitCnt() {
    let trailValue = await idBItCounts.getIDBitCnts_iTrailParityBitCnt(actConfig - 1);
    document.getElementById('trailParityBitCnt').value = parseInt(trailValue);
}

async function setActConfig() {
    if (isDeviceConnect) {
        let selectConfig = document.getElementById("config");
        let getConfig = parseInt(selectConfig.value);
        await deviceManager.setActConfig(getConfig);
        actConfig = await deviceManager.getActConfig();
        WriteLog(actConfig, "actConfigID");
        await getLeadParityBitCnt();
        await getTrailParityBitCnt();
        await getCfgFlags_bHaltKBSnd();
        await getCfgFlags_bFrcBitCntEx();
        await getCfgFlags_bSndFac();
        await getCfgFlags_bStripFac();
        await getCfgFlags3_bSndSFID();
        await getCfgFlags3_bSndSFFC();
        await getCfgFlags_bFixLenDsp();
        await getCfgFlags_bSndOnRx();
        await getCfgFlags2_bWiegInvData();
        await getCfgFlags2_bRevWiegBits();
        await getCfgFlags2_bBeepID();
        await getCfgFlags2_bRevBytes();
        await getExtendedPrecisionMath();
        await getIdExtendedPreMath();
        await getUseNumericKeypad();
        await getDisplayHexInLowercase();
        await getIDBitCnts_iIDBitCnt();
        await getCfgFlags_bFrcBitCntEx();
        await getIDDispParms_iFACDispLen();
        await getIDDispParms_iIDDispLen();
        await getAZERTYShiftLock();
        await getCardPriority();
    } else {
        alert("No Device Connected");
    }
}

async function getCfgFlags_bHaltKBSnd() {
    let flagValue = await configurationFlags.getCfgFlags_bHaltKBSnd(actConfig - 1);
    document.getElementById('bHaltKBSnd').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags_bHaltKBSnd() {
    let bHaltKBSndValue = document.getElementById('bHaltKBSnd').checked;
    await configurationFlags.setCfgFlags_bHaltKBSnd(bHaltKBSndValue, actConfig - 1);
}


async function getCfgFlags_bSndOnRx() {
    let flagValue = await configurationFlags.getCfgFlags_bSndOnRx(actConfig - 1);
    document.getElementById('bSndOnRx').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags_bSndOnRx() {
    let bSndOnRxValue = document.getElementById('bSndOnRx').checked;
    await configurationFlags.setCfgFlags_bSndOnRx(bSndOnRxValue, actConfig - 1);
}

async function setCfgFlags3_bSndSFID() {
    let isChecked, enable = 1;
    actConfig = parseInt(document.getElementById("config").value);
    let idxtendedPreMath = document.getElementById('bFrcBitCnthex');
    if (idxtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configFlags3.setCfgFlags3_bSndSFON(enable, actConfig);
    await configFlags3.setCfgFlags3_bSndSFID(isChecked, actConfig);
}

async function getCfgFlags3_bSndSFID() {
    let flagValue = await configFlags3.getCfgFlags3_bSndSFID(actConfig - 1);
    document.getElementById('bFrcBitCnthex').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags3_bSndSFFC() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let idextndedPreMath = document.getElementById('bSndSFFC');
    if (idextndedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configFlags3.setCfgFlags3_bSndSFFC(isChecked, actConfig);
}

async function getCfgFlags3_bSndSFFC() {
    let flagValue = await configFlags3.getCfgFlags3_bSndSFFC(actConfig - 1);
    document.getElementById('bSndSFFC').checked = parseInt(flagValue) ? true : false;
}

async function increaseOnlyCardReadBitsCount() {
    let onlyReadCardCount = parseInt(document.getElementById('onlyCardReadCountID').value);
    if (onlyReadCardCount >= 0 && onlyReadCardCount < 255) {
        document.getElementById('onlyCardReadCountID').value = onlyReadCardCount + 1;
        return;
    }
    if (isNaN(onlyReadCardCount)) {
        document.getElementById('onlyCardReadCountID').value = 1
    }
}

async function decreaseOnlyCardReadBitsCount() {
    let onlyReadCardCount = parseInt(document.getElementById('onlyCardReadCountID').value);
    if (onlyReadCardCount <= 0) {
        document.getElementById('onlyCardReadCountID').value = onlyReadCardCount;
    } else {
        document.getElementById('onlyCardReadCountID').value = onlyReadCardCount - 1;
    }
}

async function getCfgFlags_bFrcBitCntEx() {
    let flagValue = await configurationFlags.getCfgFlags_bFrcBitCntEx(actConfig - 1);
    document.getElementById('bFrcBitCntEx').checked = parseInt(flagValue) ? true : false;
    let totalBitCount = await idBItCounts.getIDBitCnts_iTotalBitCnt(actConfig - 1);
    document.getElementById('onlyCardReadCountID').value = parseInt(totalBitCount);
}

async function setCfgFlags_bFrcBitCntEx() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('bFrcBitCntEx');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
        let getCountValue = document.getElementById("onlyCardReadCountID").value;
        await setonlyCardReadBit(getCountValue);
    } else {
        isChecked = 0;
    }
    await configurationFlags.setCfgFlags_bFrcBitCntEx(isChecked, actConfig);
}

async function getIDBitCnts_iIDBitCnt() {
    let flagValue = await idBItCounts.getIDBitCnts_iIDBitCnt(actConfig - 1);
    document.getElementById('idFldBitCnt').value = parseInt(flagValue);
}

async function setIDBitCnts_iIDBitCnt() {
    actConfig = parseInt(document.getElementById("config").value);
    let IDfldBitCount = document.getElementById('idFldBitCnt').value;
    await idBItCounts.setIDBitCnts_iIDBitCnt(parseInt(IDfldBitCount), actConfig);
}

async function increaseidFldBitCount() {
    let onlyReadCardCount = parseInt(document.getElementById('idFldBitCnt').value);
    if (onlyReadCardCount >= 0 && onlyReadCardCount < 80) {
        document.getElementById('idFldBitCnt').value = onlyReadCardCount + 1;
        return;
    }
    if (isNaN(onlyReadCardCount)) {
        document.getElementById('idFldBitCnt').value = 1
    }
}

async function decreaseidFldBitCount() {
    let onlyReadCardCount = parseInt(document.getElementById('idFldBitCnt').value);
    if (onlyReadCardCount <= 0) {
        document.getElementById('idFldBitCnt').value = onlyReadCardCount;
    } else {
        document.getElementById('idFldBitCnt').value = onlyReadCardCount - 1;
    }
}

async function getCfgFlags_bSndFac() {
    let flagValue = await configurationFlags.getCfgFlags_bSndFac(actConfig - 1);
    document.getElementById('bSndFac').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags_bSndFac() {
    let bSndFacValue = document.getElementById('bSndFac').checked;
    actConfig = parseInt(document.getElementById("config").value);
    await configurationFlags.setCfgFlags_bSndFac(bSndFacValue, actConfig);
}

async function getCfgFlags_bStripFac() {
    let flagValue = await configurationFlags.getCfgFlags_bStripFac(actConfig - 1);
    document.getElementById('bStripFac').checked = parseInt(flagValue) ? true : false;
    isBSndFacEnabled = document.getElementById('bStripFac').checked;
}

async function setCfgFlags_bStripFac() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('bStripFac');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configurationFlags.setCfgFlags_bStripFac(isChecked, actConfig);
}

async function getCfgFlags_bFixLenDsp() {
    let flagValue = await configurationFlags.getCfgFlags_bFixLenDsp(actConfig - 1);
    document.getElementById('bFixLenDsp').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags_bFixLenDsp() {
    let bFixLenDspValue = document.getElementById('bFixLenDsp').checked;
    actConfig = parseInt(document.getElementById("config").value);
    await configurationFlags.setCfgFlags_bFixLenDsp(bFixLenDspValue, actConfig);
}

async function setExtendedPrecisionMath() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('FACPreMath');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configuration.setExtendedPrecisionMath(isChecked, actConfig);
}

async function idExtendedPreMath() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let idxtendedPreMath = document.getElementById('IDExtendedMath');
    if (idxtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configFlags3.setCfgFlags3_bUse64Bit(isChecked, actConfig);
}

async function useNumericKeypad() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let idxtendedPreMath = document.getElementById('nemuricKeypadID');
    if (idxtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configFlags3.setCfgFlags3_bUseNumKP(isChecked, actConfig);
}

async function displayHexInLowercase() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let idxtendedPreMath = document.getElementById('displayHexID');
    if (idxtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configFlags3.setCfgFlags3_bLowerCaseHex(isChecked, actConfig);
}

async function getExtendedPrecisionMath() {
    let flagValue = await configuration.getExtendedPrecisionMath(actConfig - 1);
    document.getElementById("FACPreMath").checked = parseInt(flagValue) ? true : false;
}

async function getIdExtendedPreMath() {
    let flagValue = await configFlags3.getCfgFlags3_bUse64Bit(actConfig - 1);
    document.getElementById("IDExtendedMath").checked = parseInt(flagValue) ? true : false;
}

async function getUseNumericKeypad() {
    let flagValue = await configFlags3.getCfgFlags3_bUseNumKP(actConfig - 1);
    document.getElementById("nemuricKeypadID").checked = parseInt(flagValue) ? true : false;
}

async function getDisplayHexInLowercase() {
    let flagValue = await configFlags3.getCfgFlags3_bLowerCaseHex(actConfig - 1);
    document.getElementById("displayHexID").checked = parseInt(flagValue) ? true : false;
}

async function setCurrActConfig() {
    if (isDeviceConnect) {
        await setActConfig();
        getCardType();
    } else {
        alert("No Device Connected");
    }
}

async function getCardType() {
    let cardDataValues = await fetch('./cardData.json')
        .then(rsponse => {
            return rsponse.json();
        });
    await deviceManager.setActConfig(actConfig - 1);
    let cardData = await deviceManager.getCardType();
    if (cardData != 0) {
        if ((cardData.toString(16)).length == 3) {
            let hexCardData = "0x0" + cardData.toString(16).toUpperCase();
            WriteLog(cardDataValues[hexCardData], "cardtypeID");
        } else {
            let hexCardData = "0x" + cardData.toString(16).toUpperCase();
            WriteLog(cardDataValues[hexCardData], "cardtypeID");
        }
    } else {
        WriteLog("---OFF---", "cardtypeID");
    }
    await deviceManager.setActConfig(containActConfig - 1);
}

async function writeCFG() {
    if (isDeviceConnect) {
        await setLUID();
        await setIDBitCnts_iIDBitCnt();
        await setCfgFlags_bFrcBitCntEx();
        await setIDDispParms_iFACDispLen();
        await setIDDispParms_iIDDispLen();
        await setExtendedPrecisionMath();
        await idExtendedPreMath();
        await setCardType();
        await setCfgFlags_bFixLenDsp();
        await setCfgFlags_bSndFac();
        await setCfgFlags3_bSndSFID();
        await setCfgFlags_bStripFac();
        await setCfgFlags3_bSndSFFC();
        await setActConfig();
        await deviceManager.writeCFG();
        await deviceManager.readCFG();
        alert("Write Completed!");
    }
    else {
        alert("No Device Connected");
    }
}

async function disconnect() {
    await deviceManager.disconnect();
    resetUI();
    isDeviceConnect = false;
    alert("Device Disconnected!");
}

function resetUI() {
    document.getElementById("vendor").value = '';
    document.getElementById("actConfigID").value = '';
    document.getElementById('bHaltKBSnd').checked = false;
    document.getElementById('trailParityBitCnt').value = '';
    document.getElementById('leadParityBitCnt').value = '';
    document.getElementById('databytes').value = '';
    document.getElementById("FWtextbox").value = '';
    document.getElementById("FWFile").value = '';
    document.getElementById("FWFileVersion").value = '';
    document.getElementById("LogicalUnitId").value = '';
}

async function getMaxConfig() {
    let getMaxConfig = await deviceManager.getMaxConfig() + 1;
    WriteLog(getMaxConfig, "configText");
}

async function getFirmwareVersion() {
    let cpu1bootloader = await deviceManager.getFirmwareVersion(1, 1);
    let Cpu0BootLoader = await deviceManager.getFirmwareVersion(0, 1);
    let cpu1Application = await deviceManager.getFirmwareVersion(1, 0);
    let cpu0RfFModem = await deviceManager.getFirmwareVersion(0, 2);
    let cpu0Application = await deviceManager.getFirmwareVersion(0, 0);
    let fwVersion = "CPU0 Application  : " + cpu0Application + `\n` + "CPU0 Boot Loader  : " + Cpu0BootLoader + `\n` + "CPU0 RF Modem     : " + cpu0RfFModem + `\n` + "CPU1 Application  : " + cpu1Application + `\n` + "CPU1 Boot Loader  : " + cpu1bootloader;
    WriteLog(fwVersion, "FWtextbox")
}

async function beep() {
    await deviceManager.beepNow(beepCount, islongBeep);
}

async function isBeepCountValid() {
    islongBeep = document.getElementById("LongBeeps").checked;
    if (islongBeep && beepCount > 2) {
        checkBeep = true;
        maximumBeepCount = 2;
        beepCount = 2;
    } else if (islongBeep && beepCount < 2) {
        checkBeep = true;
        maximumBeepCount = 2;
        beepCount = 1;
    } else {
        maximumBeepCount = 5;
        checkBeep = false;
    }
}

async function getBeeperVolume() {
    let volume = await deviceManager.getBeeperVolume();
    let tickBox;
    switch (volume) {
        case 0:
            tickBox = document.getElementById('off');
            break;
        case 1:
            tickBox = document.getElementById('low');
            break;
        case 2:
            tickBox = document.getElementById('medium');
            break;
        case 3:
            tickBox = document.getElementById('high');
            break;
    }
    tickBox.checked = true;
}

async function setBeeperVolume(volume) {
    await deviceManager.setBeeperVolume(volume);
}

async function getValueOfId(arrayBuffer) {
    let id = '';
    let size = arrayBuffer.length - 1;
    for (let index = size; index >= 0; index--) {
        let bufferValue = arrayBuffer[index].toString(16).toUpperCase();
        bufferValue = ('00' + bufferValue).substring(bufferValue.length);
        id += bufferValue;
    }
    let getActID = id.match(/.{1,2}/g);
    return getActID?.join(' ');
}

async function getActiveID() {
    if (isDeviceConnect) {
        let numBitsOfCard = await deviceManager.getNumBitsofCard();
        if (numBitsOfCard === 0) {
            WriteLog("No Card on Reader", "databytes");
            return;
        }
        let activeID = await deviceManager.getActiveID();
        let aciveIdStr = await getValueOfId(activeID);
        let cardByte = 'ID:' + numBitsOfCard + " Bits" + '\n' + aciveIdStr;
        WriteLog(cardByte, "databytes");
    }
    else {
        alert("No Device Connected");
    }
}

async function getActiveID32() {
    if (isDeviceConnect) {
        let numBitsOfCard = await deviceManager.getNumBitsofCard();
        if (numBitsOfCard === 0) {
            WriteLog("No Card on Reader", "databytes");
            return;
        }
        let activeID32 = await deviceManager.getActiveID32();
        let aciveId32Str = await getValueOfId(activeID32);
        let getActiveIDdata = aciveId32Str.split('');
        let data1 = getActiveIDdata.splice(0, 23).join('');
        let data2 = getActiveIDdata.splice(1, 23).join('');
        let data3 = getActiveIDdata.splice(2, 23).join('');
        let data4 = getActiveIDdata.splice(3, 23).join('');
        let dataBytes = "ID: " + numBitsOfCard + " Bits" + `\n` + data1 + `\n` + data2 + `\n` + data3 + `\n` + data4;
        WriteLog(dataBytes, "databytes");
    }
    else {
        alert("No Device Connected");
    }
}

document.addEventListener("DOMContentLoaded", function () {

    function updateBeepCount() {
        document.querySelector(".action-btn[data-action='custom']").textContent = beepCount;
    }

    function updateBeepController(action) {
        if (action === "subtract" && beepCount > 1) {
            beepCount--;
        } else if (action === "add" && beepCount < maximumBeepCount) {
            beepCount++;
        }
        updateBeepCount();
    }

    document.querySelector(".button-container").addEventListener("click", function (event) {
        const action = event.target.getAttribute("data-action");
        updateBeepController(action);
    });
    updateBeepCount();
});

function WriteLog(message, id) {
    log = document.getElementById(id);
    log.value = message;
    log.scrollTop = log.scrollHeight;
}

async function getLastLibErr() {
    let errorCode = await deviceManager.getLastLibErr();
    alert(errorCode);
}

async function getCfgFlags2_bWiegInvData() {
    let flagValue = await configurationFlags2.getCfgFlags2_bWiegInvData(actConfig - 1);
    document.getElementById('bWiegInvData').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags2_bWiegInvData() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('bWiegInvData');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configurationFlags2.setCfgFlags2_bWiegInvData(isChecked, actConfig);
}

async function getCfgFlags2_bRevWiegBits() {
    let flagValue = await configurationFlags2.getCfgFlags2_bRevWiegBits(actConfig - 1);
    document.getElementById('bRevWiegBits').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags2_bRevWiegBits() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('bRevWiegBits');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configurationFlags2.setCfgFlags2_bRevWiegBits(isChecked, actConfig);
}

async function getCfgFlags2_bBeepID() {
    let flagValue = await configurationFlags2.getCfgFlags2_bBeepID(actConfig - 1);
    document.getElementById('bBeepID').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags2_bBeepID() {
    let bBeepIDValue = document.getElementById('bBeepID').checked;
    await configurationFlags2.setCfgFlags2_bBeepID(bBeepIDValue ? 1 : 0, actConfig - 1);
}

async function getCfgFlags2_bRevBytes() {
    let flagValue = await configurationFlags2.getCfgFlags2_bRevBytes(actConfig - 1);
    document.getElementById('bRevBytes').checked = parseInt(flagValue) ? true : false;
}

async function setCfgFlags2_bRevBytes() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('bRevBytes');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configurationFlags2.setCfgFlags2_bRevBytes(isChecked, actConfig);
}

async function setAZERTYShiftLock() {
    let isChecked;
    actConfig = parseInt(document.getElementById("config").value);
    let FACExtendedPreMath = document.getElementById('azertyKeyShiftLock');
    if (FACExtendedPreMath.checked) {
        isChecked = 1;
    } else {
        isChecked = 0;
    }
    await configuration.setAZERTYShiftLock(isChecked, actConfig);
}

async function getAZERTYShiftLock() {
    let flagValue = await configuration.getAZERTYShiftLock(actConfig - 1);
    document.getElementById('azertyKeyShiftLock').checked = parseInt(flagValue) ? true : false;
}

async function setIDDispParms_iFACDispLen() {
    actConfig = parseInt(document.getElementById("config").value);
    let facDigit = parseInt(document.getElementById('idFACDigits').value);
    await idDisplayParameter.setIDDispParms_iFACDispLen(facDigit, actConfig);
}

async function getIDDispParms_iFACDispLen() {
    let flagValue = await idDisplayParameter.getIDDispParms_iFACDispLen(actConfig - 1);
    document.getElementById('idFACDigits').value = parseInt(flagValue);
}

async function increaseFacDigits() {
    let onlyReadCardCount = parseInt(document.getElementById('idFACDigits').value);
    if (onlyReadCardCount >= 0 && onlyReadCardCount < 32) {
        document.getElementById('idFACDigits').value = onlyReadCardCount + 1;
        return;
    }
    if (isNaN(onlyReadCardCount)) {
        document.getElementById('idFACDigits').value = 1
    }
}

async function decreaseFacDigits() {
    let onlyReadCardCount = parseInt(document.getElementById('idFACDigits').value);
    if (onlyReadCardCount <= 0) {
        document.getElementById('idFACDigits').value = onlyReadCardCount;
    } else {
        document.getElementById('idFACDigits').value = onlyReadCardCount - 1;
    }
}

async function setIDDispParms_iIDDispLen() {
    actConfig = parseInt(document.getElementById("config").value);
    let facDigit = parseInt(document.getElementById('idDigits').value);
    await idDisplayParameter.setIDDispParms_iIDDispLen(facDigit, actConfig);
}

async function getIDDispParms_iIDDispLen() {
    let flagValue = await idDisplayParameter.getIDDispParms_iIDDispLen(actConfig - 1);
    document.getElementById('idDigits').value = parseInt(flagValue);
}

async function increaseIdDigits() {
    let onlyReadCardCount = parseInt(document.getElementById('idDigits').value);
    if (onlyReadCardCount >= 0 && onlyReadCardCount < 32) {
        document.getElementById('idDigits').value = onlyReadCardCount + 1;
        return;
    }
    if (isNaN(onlyReadCardCount)) {
        document.getElementById('idDigits').value = 1
    }
}

async function decreaseIdDigits() {
    let onlyReadCardCount = parseInt(document.getElementById('idDigits').value);
    if (onlyReadCardCount <= 0) {
        document.getElementById('idDigits').value = onlyReadCardCount;
    } else {
        document.getElementById('idDigits').value = onlyReadCardCount - 1;
    }
}

async function setCardType() {
    actConfig = parseInt(document.getElementById("config").value);
    await deviceManager.setActConfig(actConfig);
    let cardType = document.getElementById("setCardType").value;
    let isCardPriority = (document.getElementById("cardPriorityID").checked) ? 1 : 0;
    await deviceManager.setCardTypePriority(parseInt(cardType, 16), isCardPriority);
    await deviceManager.setActConfig(containActConfig - 1);
}

async function getCardPriority() {
    await deviceManager.setActConfig(actConfig - 1);
    let flagValue = await deviceManager.getCardPriority();
    document.getElementById('getCardPriority').checked = parseInt(flagValue) ? true : false;
    await deviceManager.setActConfig(containActConfig - 1);
}