import { Component } from '@angular/core';
import cardDataJson from '../assets/cardData.json';
declare var pcprox: any

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent {
  title = 'websdk-package';
  isDeviceConnect: boolean = false;
  partNumber: string = '';
  cardType: string = '';
  configOptions: number[] = [1, 2, 3, 4];
  actConfig: number;
  containActConfig: number;
  dataBytes: string = '';
  public deviceManager = new pcprox.DeviceManager();

  async deviceConnect() {
    let checkDevice = await this.deviceManager.connect();
    if (checkDevice) {
      this.isDeviceConnect = true;
      await this.deviceManager.readCFG();
      this.actConfig = await this.deviceManager.getActConfig();
      this.containActConfig = this.actConfig;
      this.setCurrActConfig();
      this.partNumber = await this.deviceManager.getPartNumber();
      alert(`Device Connected!`);
    }
  }

  async disconnect() {
    await this.deviceManager.disconnect();
    this.partNumber = '';
    this.isDeviceConnect = false;
    this.dataBytes = '';
    alert('Device Disconnected!');
  }

  async getValueOfId(arrayBuffer: number[]) {
    let id = '';
    let size = arrayBuffer.length - 1;
    for (let index = size; index >= 0; index--) {
      let bufferValue = arrayBuffer[index].toString(16).toUpperCase();
      bufferValue = ('00' + bufferValue).substring(bufferValue.length);
      id += bufferValue;
    }
    let getActID = id.match(/.{1,2}/g);
    return getActID?.join(' ');
  }

  async getActiveID() {
    if (this.isDeviceConnect) {
      let numBitsOfCard = await this.deviceManager.getNumBitsofCard();
      if (numBitsOfCard === 0) {
        this.dataBytes = "No Card on Reader";
        return;
      }
      let activeID = await this.deviceManager.getActiveID();
      let getActiveIdstr = await this.getValueOfId(activeID);
      let cardByte = 'ID:' + numBitsOfCard + " Bits" + '\n' + getActiveIdstr;
      this.dataBytes = cardByte;
    } else {
      alert("No Device Connected");
    }
  }

  async setCurrActConfig() {
    if (this.isDeviceConnect) {
      this.actConfig = parseInt((document.getElementById('config') as HTMLSelectElement).value);
      this.getCardType();
    } else {
      alert("No Device Connected");
    }
  }

  async getCardType() {
    await this.deviceManager.readCFG();
    await this.deviceManager.setActConfig(this.actConfig);
    let cardData = await this.deviceManager.getCardType();
    if (cardData != 0) {
        if ((cardData.toString(16)).length == 3) {
            let hexCardData = "0x0" + cardData.toString(16).toUpperCase();
            let inputData = document.getElementById('cardtypeID') as HTMLInputElement;
            inputData.value = cardDataJson[hexCardData];
        } else {
            let hexCardData = "0x" + cardData.toString(16).toUpperCase();
            let inputData = document.getElementById('cardtypeID') as HTMLInputElement;
            inputData.value = cardDataJson[hexCardData];
        }
    } else {
      this.cardType = "---OFF---";
    }
    await this.deviceManager.setActConfig(this.containActConfig - 1);
  }

  async getActiveID32() {
    if (this.isDeviceConnect) {
      let numBitsOfCard = await this.deviceManager.getNumBitsofCard();
      if (numBitsOfCard === 0) {
        this.dataBytes = "No Card on Reader";
        return;
      }
      let activeID32 = await this.deviceManager.getActiveID32();
      let finalData = await this.getValueOfId(activeID32);
      let getActiveIDdata = finalData.split('');
      let data1 = getActiveIDdata.splice(0, 23).join('');
      let data2 = getActiveIDdata.splice(1, 23).join('');
      let data3 = getActiveIDdata.splice(2, 23).join('');
      let data4 = getActiveIDdata.splice(3, 23).join('');
      this.dataBytes = "ID: " + numBitsOfCard + " Bits" + `\n` + data1 + `\n` + data2 + `\n` + data3 + `\n` + data4;
    } else {
      alert("No Device Connected");
    }
  }
}
